Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(365)

Unified Diff: Source/core/css/CSSParser-in.cpp

Issue 22336008: Use the runtime flag and remove '-webkit-' prefix for CSS3 text-indent. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: patch Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/css/CSSParser-in.cpp
diff --git a/Source/core/css/CSSParser-in.cpp b/Source/core/css/CSSParser-in.cpp
index edbc75075ee64421e897194648fb9f368b0c3791..f4c4774f3ab5893203397e366d78c892239e23df 100644
--- a/Source/core/css/CSSParser-in.cpp
+++ b/Source/core/css/CSSParser-in.cpp
@@ -9136,11 +9136,13 @@ PassRefPtr<CSSValue> CSSParser::parseTextIndent()
}
}
-#if ENABLE(CSS3_TEXT)
+ if (!RuntimeEnabledFeatures::css3TextEnabled())
+ return 0;
+
// The case where text-indent has only <length>(or <percentage>) value
// is handled above if statement even though CSS3_TEXT is enabled.
// [ [ <length> | <percentage> ] && -webkit-each-line ] | inherit
if (m_valueList->size() != 2)
return 0;
@@ -9148,20 +9150,19 @@ PassRefPtr<CSSValue> CSSParser::parseTextIndent()
CSSParserValue* secondValue = m_valueList->next();
CSSParserValue* lengthOrPercentageValue = 0;
- // [ <length> | <percentage> ] -webkit-each-line
- if (validUnit(firstValue, FLength | FPercent) && secondValue->id == CSSValueWebkitEachLine)
+ // [ <length> | <percentage> ] each-line
+ if (validUnit(firstValue, FLength | FPercent) && secondValue->id == CSSValueEachLine)
lengthOrPercentageValue = firstValue;
- // -webkit-each-line [ <length> | <percentage> ]
- else if (firstValue->id == CSSValueWebkitEachLine && validUnit(secondValue, FLength | FPercent))
+ // each-line [ <length> | <percentage> ]
+ else if (firstValue->id == CSSValueEachLine && validUnit(secondValue, FLength | FPercent))
lengthOrPercentageValue = secondValue;
if (lengthOrPercentageValue) {
list->append(createPrimitiveNumericValue(lengthOrPercentageValue));
- list->append(cssValuePool().createIdentifierValue(CSSValueWebkitEachLine));
+ list->append(cssValuePool().createIdentifierValue(CSSValueEachLine));
m_valueList->next();
return list.release();
}
-#endif
return 0;
}
@@ -9136,11 +9136,13 @@ PassRefPtr<CSSValue> CSSParser::parseTextIndent()
// The case where text-indent has only <length>(or <percentage>) value
- // is handled above if statement even though CSS3_TEXT is enabled.
+ // is handled above if statement even though css3TextEnabled() returns true.
- // [ [ <length> | <percentage> ] && -webkit-each-line ] | inherit
+ // [ [ <length> | <percentage> ] && each-line ] | inherit
if (m_valueList->size() != 2)
return 0;

Powered by Google App Engine
This is Rietveld 408576698